Package: mclink
Title: Metabolic Pathway Completeness and Abundance Calculation
Version: 1.1.2
Authors@R: 
    person(given = "Liuyang",
           family = "Li",
           email = "cyanobacteria@yeah.net",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-6004-9437"))
Description: 
    Provides tools for analyzing metabolic pathway completeness, abundance, and transcripts
    using KEGG Orthology (KO) data from (meta)genomic and (meta)transcriptomic studies.
    Supports both completeness (presence/absence) and abundance-weighted analyses.
    Includes built-in KEGG reference datasets. For more details see Li et al. (2023) <doi:10.1038/s41467-023-42193-7>.
URL: https://github.com/LiuyangLee/mclink
BugReports: https://github.com/LiuyangLee/mclink/issues
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: data.table (>= 1.17.8), dplyr (>= 1.1.4), stringr (>= 1.5.1),
        tibble (>= 3.2.1), utils
Depends: R (>= 3.5)
LazyData: false
Config/check/use_internal_tz: TRUE
NeedsCompilation: no
Packaged: 2026-07-20 07:41:24 UTC; Administrator
Author: Liuyang Li [aut, cre] (ORCID: <https://orcid.org/0000-0001-6004-9437>)
Maintainer: Liuyang Li <cyanobacteria@yeah.net>
Repository: CRAN
Date/Publication: 2026-07-20 08:00:02 UTC
