# Generated by roxygen2: do not edit by hand

export(KO_Sample_wide)
export(KO_pathway_ref)
export(add_rows_if_not_exists)
export(ata_cal)
export(convert_abundance_to_presence)
export(create_sub_module_sample)
export(escape_special_chars)
export(extract_inner_brackets)
export(group_ko_by_module)
export(mclink)
export(merge_module_name)
export(process_all_modules)
export(process_all_pathways)
export(process_module_brackets)
export(process_module_definition)
export(process_module_loop_comma)
export(process_module_loop_plu_comma)
export(process_module_loop_plus)
export(process_module_step)
export(process_module_structure)
export(process_step_comma)
export(process_step_direct)
export(process_step_plus)
export(process_step_space)
export(read_and_process_KO_table)
export(read_and_process_pathway_infor)
export(remove_outer_brackets)
importFrom(dplyr,"%>%")
importFrom(utils,data)
importFrom(utils,packageVersion)
