# globals.R
utils::globalVariables(
  c(
    # Variables from data frames/tables
    "KO_Sample_table",
    "Mean_RA",
    "Orthology_Entry",
    "Module_Name",
    "Module_Entry",
    "Definition",
    "Level_2",
    "Level_3",
    "KO_Sample_wide",
    "KO_pathway_ref",
    "sub_Sample_KO_pathway",
    "."
  )
)
